/**
 * Copyright 2021 Wojtek Kosior
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of either:
 * - the GNU General Public License as published by the Free
 *   Software Foundation; either version 3 of the License, or (at
 *   your option) any later version, or
 * - the "A" license: <https://koszko.org/alicense.txt>; explained
 *   at: <https://koszko.org/en/articles/my-new-license.html>
 *
 * As additional permission under GNU GPL version 3 section 7, you
 * may distribute forms of that code without the copy of the GNU
 * GPL normally required by section 4, provided you include this
 * license notice and, in case of non-source distribution, a URL
 * through which recipients can access the Corresponding Source.
 * If you modify file(s) with this exception, you may extend this
 * exception to your version of the file(s), but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version. If you delete this
 * exception statement from all source files in the program, then
 * also delete it here.
 *
 * As a special exception to the GPL, any HTML file which merely
 * makes function calls to this code, and for that purpose
 * includes it by reference shall be deemed a separate work for
 * copyright law purposes. If you modify this code, you may extend
 * this exception to your version of the code, but you are not
 * obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

const theatre_ia = document.getElementById("theatre-ia");

let srcs = [];

let ogv_src = null;
let webm_src = null;
let mp4_src = null;

function process_link(link)
{
    ogv_src  = ogv_src  || (/\.ogv$/.test(link)  && link);
    webm_src = webm_src || (/\.webm$/.test(link) && link);
    mp4_src  = mp4_src  || (/\.mp4$/.test(link)  && link);
}

if (theatre_ia) {
    for (const a of
	 document.querySelectorAll(".item-download-options a.download-pill"))
	process_link(a.href);

    for (const link of document.querySelectorAll("link[itemprop=contentUrl]"))
	process_link(link.href);

    srcs = [
	{src: ogv_src,  type: "video/ogg"},
	{src: webm_src, type: "video/webm"},
	{src: mp4_src,  type: "video/mp4"}
    ].filter(src => src.src);
}

if (srcs.length > 0) {
    const video = document.createElement("video");

    for (const src of srcs) {
	const source = document.createElement("source");
	Object.assign(source, src);
	video.appendChild(source);
    }

    video.setAttribute("width", "100%");
    video.setAttribute("height", "auto");
    video.setAttribute("controls", "");

    for (const child of theatre_ia.children)
	child.remove();

    theatre_ia.appendChild(video);
}
